@@ -1,9 +1,7 @@
-use utf8;
-use strict;
-use warnings FATAL => 'all';
-
 package Xyzzy::CAS::Config;
 
+use Clarity -self;
+
 use Xyzzy::Util qw(parse_time parse_bool);
 
 my $have_curl;
@@ -13,7 +11,6 @@ BEGIN {
 	$have_curl_feedback = $@;
 }
 
-use Xyzzy -self;
 use Xyzzy::Crypto::Config -mixin;
 
 field cas_base_url => sub { die "Missing configuration value CASbaseURL\n" };
@@ -27,10 +24,10 @@ field cas_use_curl => $have_curl;
 field session_timeout => 36000;
 field request_timeout => 3600;
 
-*set_casbaseurl = *cas_base_url;
-*set_casloginurl = *cas_login_url;
-*set_casvalidateurl = *cas_validate_url;
-*set_casdomain = *cas_domain;
+sub set_casbaseurl; *set_casbaseurl = \&cas_base_url;
+sub set_casloginurl; *set_casloginurl = \&cas_login_url;
+sub set_casvalidateurl; *set_casvalidateurl = \&cas_validate_url;
+sub set_casdomain; *set_casdomain = \&cas_domain;
 
 sub set_casforcedomain { $self->cas_force_domain(parse_bool(shift)) }
 sub set_casforcehttps { $self->cas_force_https(parse_bool(shift)) }
