@@ -1,16 +1,12 @@
-use utf8;
-use strict;
-use warnings FATAL => 'all';
-
 package Xyzzy::Crypto::Config;
 
+use Xyzzy -self;
+
 use Digest::SHA qw(sha256);
 use Xyzzy::Util qw(parse_time);
 
-use Xyzzy -self;
-
 field cryptosecret => sub { die "no CryptoSecret configured\n" };
-*set_cryptosecret = *cryptosecret;
+sub set_cryptosecret; *set_cryptosecret = \&cryptosecret;
 
 field cryptoclockjitter => 0;
 sub set_cryptoclockjitter {
@@ -19,8 +15,8 @@ sub set_cryptoclockjitter {
 
 # 512 bits should be enough for anyone
 field cryptoseedbytes => 64;
-*set_cryptoseedbytes = *cryptoseedbytes;
+sub set_cryptoseedbytes; *set_cryptoseedbytes = \&cryptoseedbytes;
 
 # http://www.2uo.de/myths-about-urandom/
 field cryptoseedsource => '/dev/urandom';
-*set_cryptoseedsource = *cryptoseedsource;
+sub set_cryptoseedsource; *set_cryptoseedsource = \&cryptoseedsource;
