@@ -1,7 +1,3 @@
-use utf8;
-use strict;
-use warnings FATAL => 'all';
-
 package Xyzzy::Database::Config;
 
 use Clarity -self;
@@ -10,13 +6,13 @@ field db_dsn => sub { die "No db_dsn configured\n" };
 field db_user => undef;
 field db_pass => undef;
 
-*set_databasedsn = *db_dsn;
-*set_databaseusername = *db_user;
-*set_databasepassword = *db_pass;
+sub set_databasedsn; *set_databasedsn = \&db_dsn;
+sub set_databaseusername; *set_databaseusername = \&db_user;
+sub set_databasepassword; *set_databasepassword = \&db_pass;
 
-*set_db_dsn = *db_dsn;
-*set_db_user = *db_user;
-*set_db_pass = *db_pass;
+sub set_db_dsn; *set_db_dsn = \&db_dsn;
+sub set_db_user; *set_db_user = \&db_user;
+sub set_db_pass; *set_db_pass = \&db_pass;
 
 field db_options => {
 	PrintError => 0,
