@@ -113,24 +113,35 @@ my $rfc2822_weekdays = qr{Mon|Tue|Wed|Thu|Fri|Sat|Sun};
 
 sub parse_time() {
 	local $_ = shift;
-	# RFC 2822:
+	# RFC 2822
 	if(/^$rfc2822_weekdays, ([ \d]\d) ($rfc2822_months) (\d{4}) (\d{2}):(\d{2}):(\d{2}) ([+-])(\d{2})(\d{2})$/ao) {
 		local $ENV{TZ} = 'GMT';
 		return mktime(int($6), int($5), int($4), int($1), $rfc2822_months{$2}, int($3) - 1900)
 			- int("$7$8") * 3600 - int("$7$9") * 60;
 	}
 	# UNIX date(1) in C locale
-	if(/^$rfc2822_weekdays ($rfc2822_months) ([ \d]\d) (\d{2}):(\d{2}):(\d{2}) (\w+) (\d{4})$/ao) {
-		local $ENV{TZ} = $6;
-		return mktime(int($5), int($4), int($3), int($2), $rfc2822_months{$1}, int($7) - 1900);
+	# This does not work because $TZ does not understand timezone offset specifications
+	# like CEST or EDT etc. And even if it did, those abbreviations are sometimes ambiguous.
+#	if(/^$rfc2822_weekdays ($rfc2822_months) ([ \d]\d) (\d{2}):(\d{2}):(\d{2}) (\w+) (\d{4})$/ao) {
+#		local $ENV{TZ} = $6;
+#		return mktime(int($5), int($4), int($3), int($2), $rfc2822_months{$1}, int($7) - 1900);
+#	}
+	# 2014-05-14 15:16:14 +0200
+	# 2014-05-14T15:16:14+0200
+	if(/^(\d{4})-(\d{2})-(\d{2})[ T](\d{2}):(\d{2}):(\d{2})(?:\.\d+)? ?([+-])(\d{2})(\d{2})$/a) {
+		local $ENV{TZ} = 'GMT';
+		return mktime(int($6), int($5), int($4), int($3), int($2) - 1, int($1) - 1900)
+			- int("$7$8") * 3600 - int("$7$9") * 60;
 	}
 	# 2014-05-14 15:16:14 GMT
-	if(/^(\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2}):(\d{2}) (\w+)$/a) {
-		local $ENV{TZ} = $7;
+	# 2014-05-14T15:16:14Z
+	if(/^(\d{4})-(\d{2})-(\d{2})[ T](\d{2}):(\d{2}):(\d{2})(?:\.\d+)? ?(?:GMT|Z)$/a) {
+		local $ENV{TZ} = 'GMT';
 		return mktime(int($6), int($5), int($4), int($3), int($2) - 1, int($1) - 1900);
 	}
 	# 2014-05-14 15:16:14
-	if(/^(\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2}):(\d{2})$/a) {
+	# 2014-05-14T15:16:14
+	if(/^(\d{4})-(\d{2})-(\d{2})[ T](\d{2}):(\d{2}):(\d{2})(?:\.\d+)?$/a) {
 		return mktime(int($6), int($5), int($4), int($3), int($2) - 1, int($1) - 1900);
 	}
 	# 2014-05-14
@@ -176,14 +187,15 @@ field transform_params => sub {
 	my $req = shift->req;
 	return [
 		XML::LibXSLT::xpath_to_string(map {
-			my $val = eval { $req->$_() };
-			defined $val ? ($_, $val) : ()
-		} qw(
+				my $val = eval { $req->$_() };
+				defined $val ? ($_, $val) : ()
+			} qw(
 				user_agent path_info server_name server_software server_port server_protocol
 				remote_ident remote_user auth_type request_uri request_method query_string
 				script_name script_filename path_translated remote_host remote_addr referer
 				user_name virtual_host virtual_port param_string protocol base_url url_path
-				path_url url self_path self_url script_path script_url)
+				path_url url self_path self_url script_path script_url virtual_path
+			)
 		),
 		map {$_, (eval { $req->$_() } ? 'true()' : 'false()')} qw(msie secure),
 	];
