@@ -1,7 +1,3 @@
-use utf8;
-use strict;
-use warnings FATAL => 'all';
-
 package Xyzzy::Document::Config;
 
 use Clarity -self;
@@ -75,4 +71,4 @@ sub set_cachestylesheets {
 	$self->cache_stylesheets(Xyzzy::parse_bool(shift));
 }
 
-*set_cachetemplates = \&set_cachestylesheets;
+sub set_cachetemplates; *set_cachetemplates = \&set_cachestylesheets;
