@@ -7,6 +7,8 @@ package Xyzzy::LDAP;
 use URI;
 use Net::LDAP;
 use Net::LDAP::Filter;
+use Authen::SASL;
+use Scalar::Util qw(weaken);
 
 use Clarity -self;
 
@@ -21,19 +23,52 @@ field secure => sub { shift->cfg->ldap_secure };
 field cafile => sub { shift->cfg->ldap_cafile };
 field capath => sub { shift->cfg->ldap_capath };
 field schema => sub { shift->connection->schema };
+field clientcert => sub { shift->cfg->ldap_clientcert };
+field clientkey => sub { shift->cfg->ldap_clientkey };
+field ciphers => sub { shift->cfg->ldap_ciphers };
+field sslversion => sub { shift->cfg->ldap_sslversion };
+field timeout => sub { shift->cfg->ldap_timeout };
+
+field connect_options => sub {
+	my $self = shift;
+	weaken($self);
+	return {
+		onerror => sub { $self->on_error(@_) },
+		timeout => $self->timeout,
+		inet6 => 1,
+		# for ‘insecure’ connections, overruled by ssl_options:
+		verify => 'none',
+	};
+};
+
+field ssl_options => sub {
+	my $self = shift;
+	return {
+		verify => 'require',
+		(
+			map { my $value = $self->$_(); defined $value ? ($_ => $value) : () }
+				qw(cafile capath ciphers sslversion clientcert clientkey)
+		),
+	};
+};
+
+field sasl => sub { new Authen::SASL(mechanism => 'EXTERNAL') };
 
 sub bind {
 	my $ldap = shift // $self->connection;
 	my $username = $self->username;
+	return $ldap->bind unless defined $username;
+	my $password = $self->password;
 	return $ldap->bind($username, password => $self->password)
-		if $username;
-	return $ldap->bind;
+		if defined $password;
+	return $ldap->bind($username, sasl => $self->sasl) 
+		if defined $self->clientcert;
+	return $ldap->bind($username);
 }
 
 sub on_error {
 	my $obj = shift;
 	my $error = $obj->error;
-	my $code = $obj->code;
 	die $error if ref $error;
 	if($error =~ /^.* at \S+ line \d+\.?\n\z/) {
 		# evil: mess with Carp internals (if they exist) to get a clean stack trace
@@ -48,6 +83,7 @@ sub on_error {
 			confess($error);
 		}
 	}
+	my $code = $obj->code;
 	die "$error ($code)\n" if defined $code && $code > 0;
 	die "$error\n";
 }
@@ -56,11 +92,13 @@ sub connection {
 	return $self->{connection} = shift if @_;
 	# return a, possible cached, LDAP client object
 	if(my $ldap = $self->{connection}) {
-		return 1 if eval { $self->bind($ldap); 1 };
-		my $server = $self->server;
-		warn "LDAP server $server: $@"
-			unless $@ =~ /^Unexpected EOF /;
+		return $ldap if eval { $self->bind($ldap); 1 };
+		my $err = $@;
 		delete $self->{connection};
+		unless($err =~ /^Unexpected EOF /) {
+			my $server = $self->server;
+			warn "LDAP server $server: $err";
+		}
 	}
 	return $self->{connection} = $self->create_connection;
 }
@@ -68,7 +106,8 @@ sub connection {
 sub create_connection {
 	$self->schema_reset;
 	my $server = $self->server;
-	my %options = (onerror => sub { $self->on_error(@_) }, timeout => 10, inet6 => 1);
+	my $options = $self->connect_options;
+	my $ssl = $self->ssl_options;
 	my $host = $server;
 	if(index($server, '://') == -1) {
 		$host =~ s/:.*//;
@@ -78,19 +117,14 @@ sub create_connection {
 	}
 	my $ldap;
 	if($host eq 'localhost' || !$self->secure) {
-		$ldap = new Net::LDAP($server, %options)
+		$ldap = new Net::LDAP($server, %$ssl, %$options)
 			or die "Connecting to $server: $@";
 	} else {
-		my %ssl = (
-				verify => 'require',
-				capath => $self->capath,
-				cafile => $self->cafile,
-			);
 		warn "neither LDAPCAfile nor LDAPCApath configured\n"
-			unless $ssl{cafile} || $ssl{capath};
-		$ldap = new Net::LDAP($server, %options, %ssl)
+			unless exists $ssl->{cafile} || exists $ssl->{capath};
+		$ldap = new Net::LDAP($server, %$options, %$ssl)
 			or die "Connecting to $server: $@";
-		$ldap->start_tls(%ssl)
+		$ldap->start_tls(%$ssl)
 			unless $ldap->cipher;
 		die "STARTTLS failed on LDAP server $server\n"
 			unless $ldap->cipher;
@@ -120,10 +154,10 @@ sub search {
 	my $search = bless($struct, 'Net::LDAP::Filter');
 
 	return $self->connection->search(
-			base => $self->base,
-			filter => $search,
-			attrs => $attrs
-		);
+		base => $self->base,
+		filter => $search,
+		attrs => $attrs
+	);
 }
 
 sub authenticate {
