@@ -1,15 +1,11 @@
-use utf8;
-use strict;
-use warnings FATAL => 'all';
-
 package Xyzzy::Request::Root;
 
+use Clarity -self;
+
 use URI::Escape;
 use Xyzzy::Util qw(uri_escape_auto uri_unescape_plus utf8_testandset parse_path);
 use Xyzzy::MIME;
 
-use Clarity -self;
-
 field in;
 field out;
 field err;
@@ -375,7 +371,7 @@ field url_path => sub {
 	my $i = index($p, '?');
 	return $i == -1 ? $p : substr($p, 0, $i);
 };
-*path_url = \&url_path;
+sub path_url; *path_url = \&url_path;
 
 field url => sub {
 	my $self = shift;
